@@ -1,9 +1,9 @@
 """Certbot main entry point."""
 # pylint: disable=too-many-lines
 from __future__ import print_function
+
 import functools
 import logging.handlers
-import os
 import sys
 
 import configobj
@@ -14,12 +14,10 @@ from acme import errors as acme_errors
 from acme.magic_typing import Union  # pylint: disable=unused-import, no-name-in-module
 
 import certbot
-
 from certbot import account
 from certbot import cert_manager
 from certbot import cli
 from certbot import client
-from certbot import compat
 from certbot import configuration
 from certbot import constants
 from certbot import crypto_util
@@ -33,11 +31,12 @@ from certbot import reporter
 from certbot import storage
 from certbot import updater
 from certbot import util
-
+from certbot.compat import misc
+from certbot.compat import os
 from certbot.display import util as display_util, ops as display_ops
 from certbot.plugins import disco as plugins_disco
-from certbot.plugins import selection as plug_sel
 from certbot.plugins import enhancements
+from certbot.plugins import selection as plug_sel
 
 USER_CANCELLED = ("User chose to cancel the operation and may "
                   "reinvoke the client.")
@@ -224,8 +223,8 @@ def _handle_identical_cert_request(config, lineage):
         return "reinstall", lineage
     elif response[1] == 1:
         return "renew", lineage
-    else:
-        assert False, "This is impossible"
+    raise AssertionError('This is impossible')
+
 
 def _find_lineage_for_domains(config, domains):
     """Determine whether there are duplicated names and how to handle
@@ -264,6 +263,7 @@ def _find_lineage_for_domains(config, domains):
         return _handle_identical_cert_request(config, ident_names_cert)
     elif subset_names_cert is not None:
         return _handle_subset_cert_request(config, domains, subset_names_cert)
+    return None, None
 
 def _find_cert(config, domains, certname):
     """Finds an existing certificate object given domains and/or a certificate name.
@@ -342,7 +342,7 @@ def _get_added_removed(after, before):
 def _format_list(character, strings):
     """Format list with given character
     """
-    if len(strings) == 0:
+    if not strings:
         formatted = "{br}(None)"
     else:
         formatted = "{br}{ch} " + "{br}{ch} ".join(strings)
@@ -501,6 +501,7 @@ def _determine_account(config):
             raise errors.Error(
                 "Registration cannot proceed without accepting "
                 "Terms of Service.")
+        return None
 
     account_storage = account.AccountFileStorage(config)
     acme = None
@@ -548,7 +549,8 @@ def _delete_if_appropriate(config): # pylint: disable=too-many-locals,too-many-b
 
     attempt_deletion = config.delete_after_revoke
     if attempt_deletion is None:
-        msg = ("Would you like to delete the cert(s) you just revoked?")
+        msg = ("Would you like to delete the cert(s) you just revoked, along with all earlier and "
+            "later versions of the cert?")
         attempt_deletion = display.yesno(msg, yes_label="Yes (recommended)", no_label="No",
                 force_interactive=True, default=True)
 
@@ -649,6 +651,7 @@ def unregister(config, unused_plugins):
     account_files.delete(config.account)
 
     reporter_util.add_message("Account deactivated.", reporter_util.MEDIUM_PRIORITY)
+    return None
 
 
 def register(config, unused_plugins):
@@ -677,7 +680,7 @@ def register(config, unused_plugins):
     account_storage = account.AccountFileStorage(config)
     accounts = account_storage.find_all()
 
-    if len(accounts) > 0:
+    if accounts:
         # TODO: add a flag to register a duplicate account (this will
         #       also require extending _determine_account's behavior
         #       or else extracting the registration code from there)
@@ -686,7 +689,7 @@ def register(config, unused_plugins):
                 "unsupported.")
     # _determine_account will register an account
     _determine_account(config)
-    return
+    return None
 
 
 def update_account(config, unused_plugins):
@@ -709,7 +712,7 @@ def update_account(config, unused_plugins):
     reporter_util = zope.component.getUtility(interfaces.IReporter)
     add_msg = lambda m: reporter_util.add_message(m, reporter_util.MEDIUM_PRIORITY)
 
-    if len(accounts) == 0:
+    if not accounts:
         return "Could not find an existing account to update."
     if config.email is None:
         if config.register_unsafely_without_email:
@@ -732,6 +735,7 @@ def update_account(config, unused_plugins):
     account_storage.save_regr(acc, cb_client.acme)
     eff.handle_subscription(config)
     add_msg("Your e-mail address was updated to {0}.".format(config.email))
+    return None
 
 def _install_cert(config, le_client, domains, lineage=None):
     """Install a cert
@@ -759,6 +763,7 @@ def _install_cert(config, le_client, domains, lineage=None):
         path_provider.cert_path, path_provider.chain_path, path_provider.fullchain_path)
     le_client.enhance_config(domains, path_provider.chain_path)
 
+
 def install(config, plugins):
     """Install a previously obtained cert in a server.
 
@@ -816,6 +821,8 @@ def install(config, plugins):
         lineage = cert_manager.lineage_for_certname(config, config.certname)
         enhancements.enable(lineage, domains, installer, config)
 
+    return None
+
 def _populate_from_certname(config):
     """Helper function for install to populate missing config values from lineage
     defined by --cert-name."""
@@ -878,6 +885,7 @@ def plugins_cmd(config, plugins):
     logger.debug("Prepared plugins: %s", available)
     notify(str(available))
 
+
 def enhance(config, plugins):
     """Add security enhancements to existing configuration
 
@@ -934,6 +942,8 @@ def enhance(config, plugins):
     if enhancements.are_requested(config):
         enhancements.enable(lineage, domains, installer, config)
 
+    return None
+
 
 def rollback(config, plugins):
     """Rollback server configuration changes made during install.
@@ -1037,7 +1047,8 @@ def certificates(config, unused_plugins):
     """
     cert_manager.certificates(config)
 
-def revoke(config, unused_plugins):  # TODO: coop with renewal config
+# TODO: coop with renewal config
+def revoke(config, unused_plugins):
     """Revoke a previously obtained certificate.
 
     :param config: Configuration object
@@ -1079,6 +1090,7 @@ def revoke(config, unused_plugins):  # TODO: coop with renewal config
         return str(e)
 
     display_ops.success_revocation(config.cert_path[0])
+    return None
 
 
 def run(config, plugins):  # pylint: disable=too-many-branches,too-many-locals
@@ -1133,6 +1145,7 @@ def run(config, plugins):  # pylint: disable=too-many-branches,too-many-locals
         display_ops.success_renewal(domains)
 
     _suggest_donation_if_appropriate(config)
+    return None
 
 
 def _csr_get_and_save_cert(config, le_client):
@@ -1284,16 +1297,16 @@ def make_or_verify_needed_dirs(config):
 
     """
     util.set_up_core_dir(config.config_dir, constants.CONFIG_DIRS_MODE,
-                         compat.os_geteuid(), config.strict_permissions)
+                         misc.os_geteuid(), config.strict_permissions)
     util.set_up_core_dir(config.work_dir, constants.CONFIG_DIRS_MODE,
-                         compat.os_geteuid(), config.strict_permissions)
+                         misc.os_geteuid(), config.strict_permissions)
 
     hook_dirs = (config.renewal_pre_hooks_dir,
                  config.renewal_deploy_hooks_dir,
                  config.renewal_post_hooks_dir,)
     for hook_dir in hook_dirs:
         util.make_or_verify_dir(hook_dir,
-                                uid=compat.os_geteuid(),
+                                uid=misc.os_geteuid(),
                                 strict=config.strict_permissions)
 
 
@@ -1319,7 +1332,7 @@ def set_displayer(config):
     zope.component.provideUtility(displayer)
 
 
-def main(cli_args=sys.argv[1:]):
+def main(cli_args=None):
     """Command line argument parsing and main script execution.
 
     :returns: result of requested command
@@ -1328,6 +1341,8 @@ def main(cli_args=sys.argv[1:]):
     :raises errors.Error: error if plugin command is not supported
 
     """
+    if not cli_args:
+        cli_args = sys.argv[1:]
 
     log.pre_arg_parse_setup()
 
@@ -1344,7 +1359,7 @@ def main(cli_args=sys.argv[1:]):
 
     # On windows, shell without administrative right cannot create symlinks required by certbot.
     # So we check the rights before continuing.
-    compat.raise_for_non_administrative_windows_rights(config.verb)
+    misc.raise_for_non_administrative_windows_rights(config.verb)
 
     try:
         log.post_arg_parse_setup(config)
