@@ -1,6 +1,5 @@
 """Plugin common functions."""
 import logging
-import os
 import re
 import shutil
 import tempfile
@@ -12,6 +11,7 @@ import zope.interface
 from josepy import util as jose_util
 
 from acme.magic_typing import List  # pylint: disable=unused-import, no-name-in-module
+
 from certbot import achallenges  # pylint: disable=unused-import
 from certbot import constants
 from certbot import crypto_util
@@ -19,7 +19,7 @@ from certbot import errors
 from certbot import interfaces
 from certbot import reverter
 from certbot import util
-
+from certbot.compat import os
 from certbot.plugins.storage import PluginStorage
 
 logger = logging.getLogger(__name__)
@@ -301,9 +301,8 @@ class Addr(object):
             # too long, truncate
             addr_list = addr_list[0:len(result)]
         append_to_end = False
-        for i in range(0, len(addr_list)):
-            block = addr_list[i]
-            if len(block) == 0:
+        for i, block in enumerate(addr_list):
+            if not block:
                 # encountered ::, so rest of the blocks should be
                 # appended to the end
                 append_to_end = True
@@ -351,7 +350,7 @@ class ChallengePerformer(object):
     def perform(self):
         """Perform all added challenges.
 
-        :returns: challenge respones
+        :returns: challenge responses
         :rtype: `list` of `acme.challenges.KeyAuthorizationChallengeResponse`
 
 
