@@ -1,15 +1,15 @@
 """Tests for letsencrypt.plugins.selection"""
-import os
 import sys
 import unittest
 
 import mock
 import zope.component
 
+from acme.magic_typing import List  # pylint: disable=unused-import, no-name-in-module
+
 from certbot import errors
 from certbot import interfaces
-
-from acme.magic_typing import List  # pylint: disable=unused-import, no-name-in-module
+from certbot.compat import os
 from certbot.display import util as display_util
 from certbot.plugins.disco import PluginsRegistry
 from certbot.tests import util as test_util
