@@ -2,7 +2,6 @@
 import datetime
 import glob
 import logging
-import os
 import re
 import shutil
 import stat
@@ -20,6 +19,7 @@ from certbot import error_handler
 from certbot import errors
 from certbot import util
 from certbot.compat import misc
+from certbot.compat import os
 from certbot.plugins import common as plugins_common
 from certbot.plugins import disco as plugins_disco
 
@@ -238,16 +238,17 @@ def _write_live_readme_to(readme_path, is_base_dir=False):
                                     "certificates.\n".format(prefix=prefix))
 
 
-def _relevant(option):
+def _relevant(namespaces, option):
     """
     Is this option one that could be restored for future renewal purposes?
+
+    :param namespaces: plugin namespaces for configuration options
+    :type namespaces: `list` of `str`
     :param str option: the name of the option
 
     :rtype: bool
     """
     from certbot import renewal
-    plugins = plugins_disco.PluginsRegistry.find_all()
-    namespaces = [plugins_common.dest_namespace(plugin) for plugin in plugins]
 
     return (option in renewal.CONFIG_ITEMS or
             any(option.startswith(namespace) for namespace in namespaces))
@@ -262,10 +263,13 @@ def relevant_values(all_values):
     :rtype dict:
 
     """
+    plugins = plugins_disco.PluginsRegistry.find_all()
+    namespaces = [plugins_common.dest_namespace(plugin) for plugin in plugins]
+
     rv = dict(
         (option, value)
         for option, value in six.iteritems(all_values)
-        if _relevant(option) and cli.option_was_set(option, value))
+        if _relevant(namespaces, option) and cli.option_was_set(option, value))
     # We always save the server value to help with forward compatibility
     # and behavioral consistency when versions of Certbot with different
     # server defaults are used.
@@ -300,8 +304,7 @@ def full_archive_path(config_obj, cli_config, lineagename):
     """
     if config_obj and "archive_dir" in config_obj:
         return config_obj["archive_dir"]
-    else:
-        return os.path.join(cli_config.default_archive_dir, lineagename)
+    return os.path.join(cli_config.default_archive_dir, lineagename)
 
 def _full_live_path(cli_config, lineagename):
     """Returns the full default live path for a lineagename"""
@@ -509,8 +512,7 @@ class RenewableCert(object):
         server = self.configuration["renewalparams"].get("server", None)
         if server:
             return util.is_staging(server)
-        else:
-            return False
+        return False
 
     def _check_symlinks(self):
         """Raises an exception if a symlink doesn't exist"""
@@ -699,9 +701,8 @@ class RenewableCert(object):
         matches = pattern.match(os.path.basename(target))
         if matches:
             return int(matches.groups()[0])
-        else:
-            logger.debug("No matches for target %s.", kind)
-            return None
+        logger.debug("No matches for target %s.", kind)
+        return None
 
     def version(self, kind, version):
         """The filename that corresponds to the specified version and kind.
