@@ -1,12 +1,12 @@
 """Tests for certbot.hooks."""
-import os
 import stat
 import unittest
 
 import mock
-
 from acme.magic_typing import List  # pylint: disable=unused-import, no-name-in-module
+
 from certbot import errors
+from certbot.compat import os
 from certbot.tests import util
 
 
