@@ -1,7 +1,6 @@
 """Test certbot.reverter."""
 import csv
 import logging
-import os
 import shutil
 import tempfile
 import unittest
@@ -10,7 +9,7 @@ import mock
 import six
 
 from certbot import errors
-
+from certbot.compat import os
 from certbot.tests import util as test_util
 
 
@@ -348,7 +347,7 @@ class TestFullCheckpointsReverter(test_util.ConfigTestCase):
         self.assertRaises(
             errors.ReverterError, self.reverter.finalize_checkpoint, "Title")
 
-    @mock.patch("certbot.reverter.os.rename")
+    @mock.patch("certbot.reverter.misc.os_rename")
     def test_finalize_checkpoint_no_rename_directory(self, mock_rename):
 
         self.reverter.add_to_checkpoint(self.sets[0], "perm save")
